#!/opt/local/bin/python2.4

from elementtree import ElementTree as ET
import os, sys, string

# Skip .ko for now
AVAILABLE_LANGUAGES = set(
    'ar bs ch da el es fa fr he hu ii it lv ms nl pl ro sc si sl sr '
    'tr tw vi bg ca cs de en et fi gl hr ia is ja lt mk nb nn pt ru se '
    'sk sq sv tt uk'.split())

for x in AVAILABLE_LANGUAGES:

    cmd = "msgfmt -o ../locales/%s/LC_MESSAGES/tinymce.mo ../locales/%s/LC_MESSAGES/tinymce.po" % (x, x)
    os.system(cmd)



from zope.interface import implements
from zope.component import adapts
from zope.component import getUtility

try:
    import json
except:
    import simplejson as json

from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.adapters.interfaces.JSONFolderListing import IJSONFolderListing
from Products.CMFCore.interfaces._content import IContentish, IFolderish
from Products.CMFPlone.interfaces.siteroot import IPloneSiteRoot
from Products.CMFPlone.interfaces import INonStructuralFolder
from Products.CMFPlone import utils
from Products.CMFCore.utils import getUtilityByInterfaceName
from Products.CMFCore.utils import getToolByName
from Acquisition import aq_inner

class JSONFolderListing(object):
    """Returns a folderish like listing in JSON"""
    implements(IJSONFolderListing)
    #adapts(IContentish, IPloneSiteRoot)

    def __init__(self, context):
        """Constructor"""
        self.context = context

    def getBreadcrumbs(self, path=None):
        """Get breadcrumbs"""
        #TODO: getToolByName is deprecated
        ptool = getUtilityByInterfaceName('Products.CMFCore.interfaces.IPropertiesTool')
        utool = getToolByName(self.context, 'portal_url')
        portal_url = utool()
        result = []

        if path is None:
            # Add siteroot
            result.append({'title':ptool.title(),'url':portal_url})

        relative = utool.getRelativeContentPath(self.context)
        portal = utool.getPortalObject()
        start = 0

        if path is not None:
            path = path[len(portal_url)+1:-1]
            start = len(path.split('/')) - 1

        for i in range(len(relative)):
            now = relative[ :i+1 ]
            obj = aq_inner(portal.restrictedTraverse(now))

            if IFolderish.providedBy(obj):
                if not now[-1] == 'talkback':
                    result.append({'title':obj.title_or_id(),'url':portal_url + '/' + '/'.join(now)})
        return result


    def getListing(self, filter_portal_types, rooted, document_base_url, upload_type=None):
        """Returns the actual listing"""

        catalog_results = []
        results = {}

        object = aq_inner(self.context)
        portal_catalog = getToolByName(object, 'portal_catalog')

        # check if object is a folderish object, if not, get it's parent.
        if not IFolderish.providedBy(object):
            object = object.getParentNode()

        if IPloneSiteRoot.providedBy(object) or (rooted == "True" and document_base_url[:-1] == object.absolute_url()):
            results['parent_url'] = ''
        else:
            results['parent_url'] = object.getParentNode().absolute_url()

        if rooted == "True":
            results['path'] = self.getBreadcrumbs(document_base_url)
        else:
            # get all items from siteroot to context (title and url)
            results['path'] = self.getBreadcrumbs()
        
        # get all portal types and get information from brains
        path = '/'.join(object.getPhysicalPath())
        for brain in portal_catalog(portal_type=filter_portal_types, sort_on='sortable_title', path={'query': path, 'depth':1}):
            catalog_results.append({
                'id': brain.getId,
                'uid': brain.UID,
                'url': brain.getURL(),
                'portal_type': brain.portal_type,
                'title' : brain.Title == "" and brain.id or brain.Title,
                'icon' : brain.getIcon,
                'is_folderish' : brain.is_folderish
                })

        # add catalog_ressults
        results['items'] = catalog_results 
        
        # decide whether to show the upload new button
        results['upload_allowed'] = False
        if upload_type:
            portal_types = getToolByName(object, 'portal_types')
            fti = getattr(portal_types, upload_type, None)
            if fti is not None:
                results['upload_allowed'] = fti.isConstructionAllowed(object) 
        
        # return results in JSON format
        return json.dumps(results)



from zope.interface import implements
from zope.component import getUtility
from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.transforms.parser import TinyMCEOutput

try:
    try:
        from Products.PortalTransforms.interfaces import ITransform
    except ImportError:
        from Products.PortalTransforms.z3.interfaces import ITransform
except ImportError:
    ITransform = None
from Products.PortalTransforms.interfaces import itransform

try:
    from celementtree import ElementTree, HTMLTreeBuilder
except ImportError:
    from elementtree import ElementTree, HTMLTreeBuilder    

class html_to_tinymce_output_html:
    """ transform which converts html to tiny output html"""    
    if ITransform is not None:
        implements(ITransform)
    __implements__ = itransform
    __name__ = "html_to_tinymce_output_html"
    inputs = ('text/html',)
    output = "text/x-tinymce-output-html"

    def __init__(self, name=None):
        self.config_metadata = {
            'inputs' : ('list', 'Inputs', 'Input(s) MIME type. Change with care.'),
        }
        if name:
            self.__name__ = name

    def name(self):
        return self.__name__

    def convert(self, orig, data, **kwargs):
        """converts captioned images, and convert uid's to real path's"""
        # Get the context first, if None, return the original text
        context = kwargs.get('context')
        if not context is None:
            # Call the parser and transform the links and images if necessary
            tinymce_utility = getUtility(ITinyMCE)
            parser = TinyMCEOutput(context=context, captioned_images=tinymce_utility.allow_captioned_images)
            parser.feed(orig)
            parser.close()
            data.setData(parser.getResult())
        else:
            data.setData(orig)
        return data

# This needs to be here to avoid breaking existing instances
def register():
    return html_to_tinymce_output_html()



from Products.CMFCore.utils import getToolByName
from zope.interface import implements
from zope.component import getUtility
from Products.Five.browser import BrowserView

from Products.TinyMCE.browser.interfaces.url import ITinyMCEUrl

class TinyMCEUrl(BrowserView):
    """TinyMCE Url"""
    implements(ITinyMCEUrl)

    def getPathByUID(self):
        """Returns the path of an object specified in the request by UID"""

        context = self.context
        request = context.REQUEST

        if not hasattr(request, 'uid'):
            return ""

        uid = request['uid']

        reference_tool = getToolByName(context, 'reference_catalog')
        obj = reference_tool.lookupObject(uid)

        if obj:
            return obj.absolute_url()

        return ""



from Products.PythonScripts.standard import url_quote
from Products.CMFCore.utils import getToolByName
from zope.interface import implements
from zope.component import getUtility
from Products.Five.browser import BrowserView
from Acquisition import aq_inner

from Products.TinyMCE.browser.interfaces.style import ITinyMCEStyle
from Products.TinyMCE.interfaces.utility import ITinyMCE

class TinyMCEStyle(BrowserView):
    """TinyMCE Style"""
    implements(ITinyMCEStyle)

    def getStyle(self):
        """Returns a stylesheet with all content styles"""
        
        registry = getToolByName(aq_inner(self.context), 'portal_css')
        registry_url = registry.absolute_url()
        context = aq_inner(self.context)

        styles = registry.getEvaluatedResources(context)
        skinname = url_quote(aq_inner(self.context).getCurrentSkinName())
        result = []

        for style in styles:
            if style.getMedia() not in ('print', 'projection') and style.getRel()=='stylesheet' :
                src = "<!-- @import url(%s/%s/%s); -->" % (registry_url, skinname, style.getId())
                result.append(src)
        return "\n".join(result)




#!/opt/local/bin/python2.4

from elementtree import ElementTree as ET
import os, sys, string

# Skip .ko for now
AVAILABLE_LANGUAGES = set(
    'ar bs ch da el es fa fr he hu ii it lv ms nl pl ro sc si sl sr '
    'tr tw vi bg ca cs de en et fi gl hr ia is ja lt mk nb nn pt ru se '
    'sk sq sv tt uk'.split())

for x in AVAILABLE_LANGUAGES:
    tree = ET.parse("xml/%s.xml" % (x))

    root = tree.getroot()
    header = root.find('header')
    author = header.find('author').text.encode("utf-8")
    version = header.find('version')
    version_major = version.attrib['major']
    version_minor = version.attrib['minor']
    version_releasedate = version.attrib['releasedate']
    description = header.find('description').text
    description = description.replace('\n', '\\n')
    description = description.encode("utf-8")

    language = root.find('language')
    title = language.attrib['title'].encode("utf-8")
    dir = language.attrib['dir']

    if not os.path.exists("../locales/%s" % x):
        os.mkdir("../locales/%s" % x)

    if not os.path.exists("../locales/%s/LC_MESSAGES" % x):
        os.mkdir("../locales/%s/LC_MESSAGES" % x)

    FILE = open("../locales/%s/LC_MESSAGES/tinymce.po" % (x), "w")

    FILE.write("# %s\n" % description)
    FILE.write("# Version %s.%s\n" % (version_major, version_minor))
    FILE.write("#\n")
    FILE.write("# %s\n" % author)
    FILE.write("msgid \"\"\n")
    FILE.write("msgstr \"\"\n")
    FILE.write("\"Project-Id-Version: Products.TinyMCE\\n\"\n")
    FILE.write("\"POT-Creation-Date: 2000-01-01 00:00+0000\\n\"\n")
    FILE.write("\"PO-Revision-Date: %s 00:00+0000\\n\"\n" % version_releasedate)
    FILE.write("\"Last-Translator: %s\\n\"\n" % author)
    FILE.write("\"Language-Team: %s\\n\"\n" % author)
    FILE.write("\"MIME-Version: 1.0\\n\"\n")
    FILE.write("\"Content-Type: text/plain; charset=UTF-8\\n\"\n")
    FILE.write("\"Content-Transfer-Encoding: 8bit\\n\"\n")
    FILE.write("\"Plural-Forms: nplurals=1; plural=0;\\n\"\n")
    FILE.write("\"Language-Code: %s\\n\"\n" % x)
    FILE.write("\"Language-Name: %s\\n\"\n" % title)
    FILE.write("\"Preferred-Encodings: utf-8 latin1\\n\"\n")
    FILE.write("\"Domain: tinymce\\n\"\n")
    FILE.write("\n")

    for group in language.getiterator('group'):
        for item in group.getiterator('item'):
            domain = group.attrib['target']
            if domain == 'advlink':
                domain = 'plonelink'
            if domain == 'advimage':
                domain = 'ploneimage'
            if domain == 'advlink_dlg':
                domain = 'plonelink_dlg'
            if domain == 'advimage_dlg':
                domain = 'ploneimage_dlg'
            FILE.write("msgid \"%s_%s\"\n" % (domain,item.attrib['name']))
            if item.text:
                msg = item.text.replace('"', '\\"')
                msg = msg.replace('\\N', '\\n')
                msg = msg.replace('\n', '\\n')
                msg = msg.replace('\\\'', '\'')
                if msg.startswith('\\n'):
                    msg = msg[2:]
                FILE.write("msgstr \"%s\"\n" % msg.encode("utf=8"))
            else:
                FILE.write("msgstr \"\"\n")
            FILE.write("\n")

    FILE.close()



from Products.MimetypesRegistry.interfaces import IClassifier
from Products.MimetypesRegistry.MimeTypeItem import MimeTypeItem
from Products.MimetypesRegistry.common import MimeTypeException
from Products.MimetypesRegistry.interfaces import IMimetype
from zope.interface import implements
from types import InstanceType

class text_tinymce_output_html(MimeTypeItem):

    __name__   = "TinyMCE Output HTML"
    mimetypes  = ('text/x-tinymce-output-html',)
    binary     = 0



from zope.interface import implements
from zope.component import getUtility
from Products.Five.browser import BrowserView
from Acquisition import aq_inner

from Products.TinyMCE.adapters.interfaces.JSONFolderListing import IJSONFolderListing
from Products.TinyMCE.adapters.interfaces.JSONSearch import IJSONSearch
from Products.TinyMCE.adapters.interfaces.JSONDetails import IJSONDetails
from Products.TinyMCE.adapters.interfaces.Upload import IUpload
from Products.TinyMCE.adapters.interfaces.Save import ISave
from Products.TinyMCE.browser.interfaces.browser import ITinyMCEBrowserView
from Products.TinyMCE.interfaces.utility import ITinyMCE

class TinyMCEBrowserView(BrowserView):
    """TinyMCE Browser View"""
    implements(ITinyMCEBrowserView)

    def upload(self):
        """Upload a file to the zodb"""

        context = aq_inner(self.context)
        object = IUpload(self.context)
        return object.upload()

    def save(self, text, fieldname):
        """Saves the specified richedit field"""

        context = aq_inner(self.context)
        object = ISave(self.context)
        return object.save(text, fieldname)

    def jsonLinkableFolderListing(self, rooted, document_base_url):
        """Returns the folderlisting of linkable objects in JSON"""

        utility = getUtility(ITinyMCE)
        linkable_portal_types = utility.linkable.split('\n')

        context = aq_inner(self.context)
        object = IJSONFolderListing(self.context)
        results = object.getListing(linkable_portal_types, rooted, document_base_url, 'File') 
        return results

    def jsonImageFolderListing(self, rooted, document_base_url):
        """Returns the folderlisting of image objects in JSON"""

        utility = getUtility(ITinyMCE)
        image_portal_types = utility.imageobjects.split('\n')
        image_portal_types.extend(utility.containsobjects.split('\n'))

        context = aq_inner(self.context)
        object = IJSONFolderListing(self.context)
        results = object.getListing(image_portal_types, rooted, document_base_url, 'Image')
        return results

    def jsonLinkableSearch(self, searchtext):
        """Returns the search results of linkable objects in JSON"""

        utility = getUtility(ITinyMCE)
        linkable_portal_types = utility.linkable.split('\n')
        linkable_portal_types.extend(utility.containsobjects.split('\n'))

        context = aq_inner(self.context)
        object = IJSONSearch(self.context)
        results = object.getSearchResults(linkable_portal_types, searchtext)
        return results

    def jsonImageSearch(self, searchtext):
        """Returns the search results of image objects in JSON"""

        utility = getUtility(ITinyMCE)
        image_portal_types = utility.imageobjects.split('\n')
        image_portal_types.extend(utility.containsobjects.split('\n'))

        context = aq_inner(self.context)
        object = IJSONSearch(self.context)
        results = object.getSearchResults(image_portal_types, searchtext)
        return results

    def jsonDetails(self):
        """Returns the details of an object in JSON"""

        context = aq_inner(self.context)
        object = IJSONDetails(self.context)
        return object.getDetails()
    
    
        



from zope.interface import implements
from zope.formlib import form
from zope.i18nmessageid import MessageFactory
from plone.fieldsets.fieldsets import FormFieldsets

from plone.app.controlpanel.form import ControlPanelForm

from Products.Five.formlib import formbase
from Acquisition import aq_inner
from Products.Five.browser import BrowserView

from Products.CMFCore.utils import getToolByName
from Products.PythonScripts.standard import html_quote, newline_to_br

from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.interfaces.utility import ITinyMCELayout
from Products.TinyMCE.interfaces.utility import ITinyMCEToolbar
from Products.TinyMCE.interfaces.utility import ITinyMCELibraries
from Products.TinyMCE.interfaces.utility import ITinyMCEResourceTypes

from Products.TinyMCE.browser.interfaces.controlpanel import ITinyMCEControlPanelForm
from Products.TinyMCE.setuphandlers import install_mimetype_and_transforms, uninstall_mimetype_and_transforms

_ = MessageFactory('plone.tinymce')

class TinyMCEControlPanelForm(ControlPanelForm):
    """TinyMCE Control Panel Form"""
    implements(ITinyMCEControlPanelForm)

    tinymcelayout = FormFieldsets(ITinyMCELayout)
    tinymcelayout.id = 'tinymcelayout'
    tinymcelayout.label = _(u'Layout')

    tinymcetoolbar = FormFieldsets(ITinyMCEToolbar)
    tinymcetoolbar.id = 'tinymcetoolbar'
    tinymcetoolbar.label = _(u'Toolbar')

    tinymcelibraries = FormFieldsets(ITinyMCELibraries)
    tinymcelibraries.id = 'tinymcelibraries'
    tinymcelibraries.label = _(u'Libraries')

    tinymceresourcetypes = FormFieldsets(ITinyMCEResourceTypes)
    tinymceresourcetypes.id = 'tinymceresourcetypes'
    tinymceresourcetypes.label = _(u'Resource Types')

    form_fields = FormFieldsets(tinymcelayout, tinymcetoolbar, tinymceresourcetypes) # tinymcelibraries

    label = _(u"TinyMCE Settings")
    description = _(u"Settings for the TinyMCE Wysiwyg editor.")
    form_name = _("TinyMCE Settings")

    def _on_save(self, data=None):
        """On save event handler"""
        if self.context.link_using_uids or self.context.allow_captioned_images:
            # We need to register our mimetype and transforms for uid links and captioned_images
            install_mimetype_and_transforms(self.context)
        else:
            # Unregister them
            uninstall_mimetype_and_transforms(self.context)



from zope.interface import Interface

class IJSONFolderListing(Interface):
    """Returns a folderish like listing in JSON"""

    def __init__(self, context):
        """Constructor"""

    def getBreadcrumbs(self):
        """Get breadcrumbs"""

    def getListing(self, filter_portal_types, rooted, document_base_url, upload_type=None):
        """Returns the actual listing"""



from Products.CMFCore.utils import getToolByName
from Products.TinyMCE.setuphandlers import uninstall_mimetype_and_transforms, remove_editor, unregisterUtility

def uninstall(portal, reinstall=False):

    if not reinstall:

        # normal uninstall
        setup_tool = getToolByName(portal, 'portal_setup')
        setup_tool.runAllImportStepsFromProfile('profile-Products.TinyMCE:uninstall')

        # http://plone.org/products/tinymce/issues/44
        uninstall_mimetype_and_transforms(portal)

        # Remove TinyMCE as a possible editor
        remove_editor(portal)

        # remove utility
        unregisterUtility(portal)

        return "Ran all uninstall steps."



from zope.interface import Interface

class IUpload(Interface):
    """Adds the uploaded file to the folder"""

    def __init__(self, context):
        """Constructor"""

    def errorMessage(self, msg):
        """Returns an error message"""

    def okMessage(self, msg):
        """Returns an ok message"""

    def cleanupFilename(self, name):
        """Generate a unique id which doesn't matc the system generated ids"""

    def upload(self):
        """Adds uploaded file"""


"""
   Usage: rebuild-pot.py
"""

import os, sys, string

try:
    import win32api
    WIN32 = True
except ImportError:
    WIN32 = False

__WGET = os.environ.get('WGET', 'wget')

AVAILABLE_LANGUAGES = set(
    'ar bs ch da el es fa fr he hu ii it lv ms nl pl ro sc si sl sr '
    'tr tw vi bg ca cs de en et fi gl hr ia is ja lt mk nb nn pt ru se '
    'sk sq sv tt uk'.split())

def main():

    if not os.path.exists('xml'):
        os.mkdir('xml')

    for x in AVAILABLE_LANGUAGES:

        cmd = __WGET + (' -O xml/%s.xml "http://services.moxiecode.com/i18n/download.aspx?format=xml&code=%s&product=tinymce"') % (x, x)
        os.system(cmd)

if __name__ == '__main__':
    main()
